==> nextcloud-14.0.1.tgz: nextcloud/apps/comments/l10n/hu.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Hozzászólás szerkesztése",
    "Delete comment" : "Hozzászólás törlése",
    "New comment …" : "Új hozzászólás...",
    "Post" : "Küldés",
    "Cancel" : "Mégsem",
    "[Deleted user]" : "[Törölt felhasználó]",
    "Comments" : "Hozzászólások",
    "No comments yet, start the conversation!" : "Még nincsenek hozzászólások, kezdd el a beszélgetést!",
    "More comments …" : "Több hozzászólás...",
    "Save" : "Mentés",
    "Allowed characters {count} of {max}" : "Engedélyezett karakterek: {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "Hiba a {id} számú komment betöltésekor",
    "Error occurred while updating comment with id {id}" : "Hiba a következő azonosítójú hozzászólás frissítése közben: {id}",
    "Error occurred while posting comment" : "Hiba történt a hozzászólás küldése közben",
    "_%n unread comment_::_%n unread comments_" : ["%n olvasatlan hozzászólás","%n olvasatlan hozzászólás"],
    "Comment" : "Hozzászólás",
    "You commented" : "Hozzászóltál",
    "%1$s commented" : "%1$s hozzászólt",
    "{author} commented" : "{author} hozzászólt",
    "You commented on %1$s" : "Hozzászoltál ehhez: %1$s",
    "You commented on {file}" : "Hozzászóltál ehhez: {file}",
    "%1$s commented on %2$s" : "%1$s hozzászólt ehhez: %2$s",
    "{author} commented on {file}" : "{author} hozzászólt ehhez: {file}",
    "<strong>Comments</strong> for files" : "<strong>Hozzászólások</strong> fájlokhoz",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Megemlítettek ezen: “%s”, egy már törölt felhasználó hozzászólásában",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Megemlítettek ezen: “{file}”, egy már törölt felhasználó hozzászólásában",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s megemlített egy hozzászólásban itt: “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} megemlített egy hozzászólásban itt: “{file}”",
    "Unknown user" : "Ismeretlen felhasználó",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Egy (most) törölt felhasználó megemlített egy hozzászólásban itt: “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Egy (most) törölt felhasználó megemlített egy hozzászólásban itt: “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/comments/l10n/hu.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Hozzászólások",
    "You commented" : "Hozzászóltál",
    "%1$s commented" : "%1$s hozzászólt",
    "{author} commented" : "{author} hozzászólt",
    "You commented on %1$s" : "Hozzászoltál ehhez: %1$s",
    "You commented on {file}" : "Hozzászóltál ehhez: {file}",
    "%1$s commented on %2$s" : "%1$s hozzászólt ehhez: %2$s",
    "{author} commented on {file}" : "{author} hozzászólt ehhez: {file}",
    "<strong>Comments</strong> for files" : "<strong>Hozzászólások</strong> fájlokhoz",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Megemlítettek ezen: “{file}”, egy már törölt felhasználó hozzászólásában",
    "{user} mentioned you in a comment on “{file}”" : "{user} megemlített egy hozzászólásban itt: “{file}”",
    "Files app plugin to add comments to files" : "Beépülő Fájl applikáció amivel megjegyzések adhatók fájlokhoz ",
    "Edit comment" : "Hozzászólás szerkesztése",
    "Delete comment" : "Hozzászólás törlése",
    "New comment …" : "Új hozzászólás...",
    "Post" : "Küldés",
    "Cancel" : "Mégsem",
    "[Deleted user]" : "[Törölt felhasználó]",
    "No comments yet, start the conversation!" : "Még nincsenek hozzászólások, kezdd el a beszélgetést!",
    "More comments …" : "Több hozzászólás...",
    "Save" : "Mentés",
    "Allowed characters {count} of {max}" : "Engedélyezett karakterek: {count} / {max}",
    "Error occurred while retrieving comment with ID {id}" : "Hiba a {id} számú hozzászólás betöltésekor",
    "Error occurred while updating comment with id {id}" : "Hiba a következő azonosítójú hozzászólás frissítése közben: {id}",
    "Error occurred while posting comment" : "Hiba történt a hozzászólás küldése közben",
    "_%n unread comment_::_%n unread comments_" : ["%n olvasatlan hozzászólás","%n olvasatlan hozzászólás"],
    "Comment" : "Hozzászólás",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Megemlítettek ezen: “%s”, egy már törölt felhasználó hozzászólásában",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s megemlített egy hozzászólásban itt: “%2$s”"
},
"nplurals=2; plural=(n != 1);");
